import { ulid } from "ulid";
import { hash } from "argon2";

import { Account } from "./entities/account.js";
import MercuryDataSource from "./index.js";

const missingAuthData = new Error("missing auth data for local user");

/** Creates a new account. */
export async function createAccount(
  username: string,
  host: string | null,
  auth: { email: string; password: string } | null
) {
  if (auth && (!auth.email || !auth.password)) throw missingAuthData;

  const account = new Account();
  account.id = ulid();
  account.username = username;
  account.host = host;
  if (auth) {
    account.email = auth.email;
    account.password = await hash(auth.password);
  }

  await MercuryDataSource.getRepository(Account).save(account);

  return account;
}
